@@ -9,13 +9,14 @@ from flask_sqlalchemy import SQLAlchemy
 
 from prometheus_client import generate_latest
 from prometheus_client.core import GaugeMetricFamily
+
 from prometheus_flask_exporter import PrometheusMetrics
 
 from sqlalchemy.dialects import registry
 
 from werkzeug.middleware.proxy_fix import ProxyFix
 
-from .config import app_prefix, config_by_name
+from .config import config_by_name
 
 from .util.prometheus_helper import prometheus_multiproc_dir, get_registry, register_collector, unregister_collector
 
@@ -29,7 +30,9 @@ registry.register('db2.ibm_db_sa', __package__ + '.database.db2.dialect', 'MyDB2
 
 aps = APScheduler()
 
-metrics = PrometheusMetrics(app=None, registry=get_registry('application'))
+app_registry_name = 'application'
+
+metrics = PrometheusMetrics.for_app_factory(registry=get_registry(app_registry_name))
 
 registered_collectors = {}
 
@@ -37,6 +40,8 @@ job_collector_metrics = {}
 
 
 def create_app(config_name):
+    from .. import blueprint
+
     app = Flask(__name__)
 
     app.wsgi_app = ProxyFix(app.wsgi_app)
@@ -56,6 +61,8 @@ def create_app(config_name):
 
         aps.init_app(app)
         metrics.init_app(app)
+
+        app.register_blueprint(blueprint)
     except ValueError as error:
         app.logger.critical(error)
         exit(1)
@@ -83,16 +90,16 @@ def delete_job(job_name, pushgateways):
 
 
 def get_jobs():
-    jobs = aps.app.config.get('JOBS')
+    job_list = aps.app.config.get('SCHEDULER_JOBS')
 
     return [
-        job['id'] for job in jobs
+        job['id'] for job in job_list
     ]
 
 
 def init_scheduler(config_name):
     try:
-        jobs = aps.app.config.get('JOBS')
+        job_list = aps.app.config.get('SCHEDULER_JOBS')
 
         config_obj = config_by_name[config_name]()
 
@@ -101,7 +108,7 @@ def init_scheduler(config_name):
 
         aps.app.config.from_object(config_obj)
 
-        aps.app.config['JOBS'] = jobs
+        aps.app.config['SCHEDULER_JOBS'] = job_list
 
         source_refresh_interval = aps.app.config.get('JOBS_SOURCE_REFRESH_INTERVAL')
 
@@ -120,18 +127,6 @@ def init_scheduler(config_name):
         exit(1)
 
 
-def run_scheduler(run_jobs=True):
-    aps.start()
-
-    initial_run_time = datetime.now() + timedelta(seconds=5)
-
-    for job_name in get_jobs():
-        if run_jobs:
-            aps.modify_job(job_name, next_run_time=initial_run_time)
-        else:
-            aps.pause_job(job_name)
-
-
 def set_job_collector_metrics(job_name, collector_metrics):
     job_collector_metrics[job_name] = collector_metrics
 
@@ -162,6 +157,22 @@ def set_job_collector_metrics(job_name, collector_metrics):
                 aps.app.logger.warning("Failed sending metrics for job '" + job_name + "' to Pushgateway service '" + service + "'. " + type(e).__name__ + ": " + str(e))
 
 
+def shutdown_scheduler():
+    aps.shutdown()
+
+
+def start_scheduler(run_jobs=True):
+    aps.start()
+
+    initial_run_time = datetime.now() + timedelta(seconds=5)
+
+    for job_name in get_jobs():
+        if run_jobs:
+            aps.modify_job(job_name, next_run_time=initial_run_time)
+        else:
+            aps.pause_job(job_name)
+
+
 def update_jobs(source_refresh_job_name, config_name):
     try:
         aps.app.logger.info("Check for job updates started.")
@@ -173,7 +184,7 @@ def update_jobs(source_refresh_job_name, config_name):
 
             config_obj.add_jobs_from_source(aa)
 
-        job_list = aps.app.config.get('JOBS')
+        job_list = aps.app.config.get('SCHEDULER_JOBS')
 
         pushgateways = config_obj.PUSHGATEWAYS
 
@@ -191,22 +202,22 @@ def update_jobs(source_refresh_job_name, config_name):
             else:
                 jobs[job_name] = job_list[i]
 
-        for i in range(len(config_obj.JOBS)):
-            job_name = config_obj.JOBS[i]['id']
+        for i in range(len(config_obj.SCHEDULER_JOBS)):
+            job_name = config_obj.SCHEDULER_JOBS[i]['id']
 
             run_job = True
 
             if job_name in jobs.keys():
-                run_job = json.dumps(config_obj.JOBS[i]) != json.dumps(jobs[job_name])
+                run_job = json.dumps(config_obj.SCHEDULER_JOBS[i]) != json.dumps(jobs[job_name])
 
                 if run_job:
                     delete_job(job_name, pushgateways)
 
-                    aps.modify_job(**config_obj.JOBS[i])
+                    aps.modify_job(**config_obj.SCHEDULER_JOBS[i])
 
                     aps.app.logger.info("Job '" + job_name + "' updated.")
             else:
-                aps.add_job(**config_obj.JOBS[i])
+                aps.add_job(**config_obj.SCHEDULER_JOBS[i])
 
                 aps.app.logger.info("Job '" + job_name + "' added.")
 
