@@ -10,25 +10,13 @@ if __package__ is None:
 
     sys.path.append(os.path.dirname(sys.path[0]))
 
-from .app.main import create_app, init_scheduler, run_scheduler
-
-
-def register_blueprint():
-    global app
-
-    from .app import blueprint
-
-    app.register_blueprint(blueprint)
+from .app.main import create_app, init_scheduler, start_scheduler
 
 
 config_name = os.getenv('BOILERPLATE_ENV', 'dev')
 
 app = create_app(config_name)
 
-register_blueprint()
-
-app.app_context().push()
-
 manager = Manager(app)
 
 host = os.getenv('CF_INSTANCE_INTERNAL_IP', os.getenv('IP_ADDRESS', '127.0.0.1'))
@@ -47,7 +35,7 @@ def run():
     if not (app.debug and os.getenv('WERKZEUG_RUN_MAIN') is None):
         init_scheduler(config_name)
 
-        run_scheduler()
+        start_scheduler()
 
     app.run(host=host, port=port)
 
